
From: Dmitry Torokhov <dtor_core@ameritech.net>

I8K: Switch to using module_param, allow switching 'power_status' through
sysfs.

Signed-off-by: Dmitry Torokhov <dtor@mail.ru>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/Documentation/kernel-parameters.txt |    8 ++++++++
 25-akpm/drivers/char/i8k.c                  |   16 +++++++++-------
 2 files changed, 17 insertions(+), 7 deletions(-)

diff -puN Documentation/kernel-parameters.txt~export-power_status-parameter-through-sysfs Documentation/kernel-parameters.txt
--- 25/Documentation/kernel-parameters.txt~export-power_status-parameter-through-sysfs	Wed Oct 27 15:38:23 2004
+++ 25-akpm/Documentation/kernel-parameters.txt	Wed Oct 27 15:38:23 2004
@@ -490,6 +490,14 @@ running once the system is up.
 
 	i810=		[HW,DRM]
 
+	i8k.force	[HW] Activate i8k driver even if SMM BIOS signature
+			does not match list of supported models.
+	i8k.power_status
+			[HW] Report power status in /proc/i8k
+			(disabled by default)
+	i8k.restricted	[HW] Allow controlling fans only if SYS_ADMIN
+			capability is set.
+
 	ibmmcascsi=	[HW,MCA,SCSI] IBM MicroChannel SCSI adapter
 			See Documentation/mca.txt.
 
diff -puN drivers/char/i8k.c~export-power_status-parameter-through-sysfs drivers/char/i8k.c
--- 25/drivers/char/i8k.c~export-power_status-parameter-through-sysfs	Wed Oct 27 15:38:23 2004
+++ 25-akpm/drivers/char/i8k.c	Wed Oct 27 15:38:23 2004
@@ -65,18 +65,20 @@ static char product_name [48] = "?";
 static char bios_version [4]  = "?";
 static char serial_number[16] = "?";
 
-static int force = 0;
-static int restricted = 0;
-static int power_status = 0;
-
 MODULE_AUTHOR("Massimo Dal Zotto (dz@debian.org)");
 MODULE_DESCRIPTION("Driver for accessing SMM BIOS on Dell laptops");
 MODULE_LICENSE("GPL");
-MODULE_PARM(force, "i");
-MODULE_PARM(restricted, "i");
-MODULE_PARM(power_status, "i");
+
+static int force;
+module_param(force, bool, 0);
 MODULE_PARM_DESC(force, "Force loading without checking for supported models");
+
+static int restricted;
+module_param(restricted, bool, 0);
 MODULE_PARM_DESC(restricted, "Allow fan control if SYS_ADMIN capability set");
+
+static int power_status;
+module_param(power_status, bool, 600);
 MODULE_PARM_DESC(power_status, "Report power status in /proc/i8k");
 
 static ssize_t i8k_read(struct file *, char __user *, size_t, loff_t *);
_
